@@ -1,10 +1,12 @@
+from typing import Dict, Any
+from enum import Enum
 from pathlib import Path
 from clease import jsonio
 
 __all__ = ["save_app_data", "load_app_data", "AppDataKeys"]
 
 
-class AppDataKeys:
+class AppDataKeys(str, Enum):
     """Collection of keys which (may) be in the app_data.
     Keys starting with an '_' will not be saved in the app state."""
 
@@ -23,8 +25,26 @@ class AppDataKeys:
     # instance of an Evaluate class
     EVALUATE = "_evaluator"
 
+    @classmethod
+    def is_key_private(cls, key: str) -> bool:
+        """Check if a given key is considered 'private'"""
+        return key.startswith("_")
 
-def save_app_data(app_data, fname):
+    @classmethod
+    def is_key_public(cls, key: str) -> bool:
+        """Check if a given key is considered 'public'"""
+        return not cls.is_key_private(key)
+
+    @classmethod
+    def iter_public_keys(cls):
+        yield from filter(cls.is_key_public, cls)
+
+    @classmethod
+    def iter_private_keys(cls):
+        yield from filter(cls.is_key_private, cls)
+
+
+def save_app_data(app_data: Dict[str, Any], fname):
     fname = Path(fname)
     data = app_data.copy()
     to_remove = []
@@ -32,7 +52,7 @@ def save_app_data(app_data, fname):
         # Find keys which we don't want to save
         # Any keys starting with a "_" we say
         # we don't want to save
-        if key.startswith("_"):
+        if AppDataKeys.is_key_private(key):
             to_remove.append(key)
     for key in to_remove:
         data.pop(key, None)
