@@ -1,14 +1,16 @@
 import logging
 import uuid
-import threading
 from IPython.display import display, clear_output
 import ipywidgets as widgets
 import numpy as np
+import ase
 import clease
 from clease.montecarlo import constraints
 from clease_gui import register_logger, utils
 from clease_gui.base_dashboard import BaseDashboard
 from clease_gui.status_bar import update_statusbar
+from clease_gui.utils import make_clickable_button
+from clease.montecarlo import observers
 
 __all__ = ["CanonicalMC"]
 
@@ -26,6 +28,8 @@ class CanonicalMC(BaseDashboard):
         self._mc = None  # MC process
         super().__init__(*args, **kwargs)
 
+        self.step_move_obs = None
+
     def initialize(self):
         # Temperature widgets
 
@@ -87,7 +91,6 @@ class CanonicalMC(BaseDashboard):
         )
 
         # Number of steps
-
         self.step_widgets = {}
         sweeps_widget = widgets.BoundedIntText(
             description="Number of sweeps:",
@@ -127,8 +130,9 @@ class CanonicalMC(BaseDashboard):
 
         self.step_mode_widget.observe(_on_step_mode_change)
 
-        self.run_mc_button = widgets.Button(description="Run MC", button_style="primary")
-        self.run_mc_button.on_click(self._on_run_mc_click)
+        self.run_mc_button = make_clickable_button(
+            self._on_run_mc_click, description="Run MC", button_style="primary"
+        )
 
         self.update_atoms_after_run_widget = widgets.Checkbox(
             description="Update supercell after MC run?", value=True
@@ -150,6 +154,18 @@ class CanonicalMC(BaseDashboard):
             **self.DEFAULT_STYLE_KWARGS,
         )
 
+        self.step_observer_wdgt = widgets.Dropdown(
+            options=[
+                ("Off", "off"),
+                # Values for the "only_accept" parameter
+                ("Every step", False),
+                ("Accepted steps", True),
+            ],
+            description="Observe steps:",
+            value="off",
+            **self.DEFAULT_STYLE_KWARGS,
+        )
+
     def attach_constraints(
         self,
         mc: clease.montecarlo.Montecarlo,
@@ -192,6 +208,7 @@ class CanonicalMC(BaseDashboard):
 
         display(step_mode_box, self.steps_output)
         display(self.temperature_mode_widget, self.temp_mode_output)
+        display(self.step_observer_wdgt)
         display(frq_box, self.constrain_sublattices_wdgt)
         display(self.clear_mc_app_data_button)
 
@@ -265,7 +282,7 @@ class CanonicalMC(BaseDashboard):
         return value
 
     @property
-    def atoms(self):
+    def atoms(self) -> ase.Atoms:
         return self._get_key(self.KEYS.SUPERCELL)
 
     @property
@@ -289,7 +306,6 @@ class CanonicalMC(BaseDashboard):
 
         # attach a CLEASE calculator
         atoms = clease.calculator.attach_calculator(settings, atoms, eci=eci)
-
         mc = clease.montecarlo.Montecarlo(atoms, temp)
         mc.status_every_sec = self.update_freq
 
@@ -345,26 +361,21 @@ class CanonicalMC(BaseDashboard):
             missing_keys = ", ".join(missing_keys)
             raise KeyError(f'Missing the following in app data: "{missing_keys}".')
 
+    @update_statusbar
     def _run_mc_in_thread(self) -> None:
         """Start the `_run_mc` method in a separate thread,
         while also disabling the run mc button for the duration
         of the run
         """
 
-        @update_statusbar
-        def runner(self):
-            """Helper function to be executed by the thread"""
-            # Disable the run MC button while an MC thread is running
-            with utils.disable_widget_context(self.run_mc_button):
-                with self.event_context(logger=logger):
-                    self._run_mc()
-
         # First we check if we have all necessary quantities, before
         # launching the thread
         self._check_required_keys()
 
-        # The update_statusbar decorator assumes "self" is the first argument
-        threading.Thread(target=runner, args=(self,), daemon=True).start()
+        # May be run in a separate process, eventually. For now, use main thread.
+        with utils.disable_widget_context(self.run_mc_button):
+            with self.event_context(logger=logger):
+                self._run_mc()
 
     def _run_mc(self):
         """Execute the MC run at the currnet settings."""
@@ -390,9 +401,18 @@ class CanonicalMC(BaseDashboard):
 
         mc = self._make_mc_object(atoms)
         # Add emin observer
-        emin_obs = clease.montecarlo.observers.LowestEnergyStructure(mc.atoms)
+        emin_obs = observers.LowestEnergyStructure(mc.atoms)
         mc.attach(emin_obs)
         self._mc = mc
+
+        # Add move observer
+        _step_val = self.step_observer_wdgt.value
+        self.step_move_obs = None
+        if _step_val != "off":
+            self.step_move_obs = observers.MoveObserver(atoms, only_accept=_step_val)
+            mc.attach(self.step_move_obs)
+        self.app_data["_mc_step_obs"] = self.step_move_obs
+
         # Initialize the progress bar
         self.mc_progress.value = 0
         self.mc_progress.max = n_temp
@@ -410,7 +430,7 @@ class CanonicalMC(BaseDashboard):
                 check_abort(mc)
                 mc.T = temp
                 steps = self.get_number_of_steps()
-                initial_energy = mc.atoms.get_potential_energy()
+                initial_energy = mc.current_energy
 
                 # some debugging logging
                 logger.debug(
